config

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package config reads a yaml config file from the XDG_CONFIG_HOME and unmarshals it into a user supplied struct

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get[T any]() (*T, error)

Get returns the configuration data for the supplied configuration struct type T, caching it after first retrieval.

Types

This section is empty.

Jump to